<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Attiva il plugin',
	'affichage' => 'Visualizzazione',
	'aide_non_disponible' => 'Questa parte della guida in linea non è ancora disponibile in italiano.',
	'annuler_recherche' => 'Annullare la ricerca',
	'auteur' => 'Autrice:',
	'avis_acces_interdit' => 'Accesso vietato.',
	'avis_article_modifie' => 'Attenzione, @nom_auteur_modif@ ha lavorato su quest’articolo @date_diff@ minuti fa',
	'avis_aucun_resultat' => 'Nessun risultato.',
	'avis_base_inaccessible' => 'Impossibile connettersi al database @base@.',
	'avis_chemin_invalide_1' => 'il percorso che hai scelto',
	'avis_chemin_invalide_2' => 'non sembra valido. Torna alla pagina precedente e verifica le informazioni fornite.',
	'avis_connexion_echec_1' => 'il collegamento alla base di dati è fallito.',
	'avis_connexion_echec_2' => 'torna alla pagina precedente e verifica le informazioni fornite.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Spesso sul server si deve <b>chiedere</b> l’attivazione dell’accesso alla base di dati prima di poterlo utilizzare. Se è impossibile collegarsi, verificare la configurazione per la connessione con l’amministratrice del sistema.',
	'avis_connexion_erreur_nom_base' => 'Il nome del database può contenere solo lettere, cifre e tratti',
	'avis_connexion_ldap_echec_1' => 'La connessione al server LDAP è fallita.',
	'avis_connexion_ldap_echec_2' => 'Torna alla pagina precedente e verifica le informazioni fornite. ',
	'avis_connexion_ldap_echec_3' => 'In alternativa, non utilizzare il supporto LDAP per importare utenti.',
	'avis_deplacement_rubrique' => 'Attenzione! Questa rubrica contiene @contient_breves@ breve/i: se vuoi spostarla, spunta questa casella per confermare.',
	'avis_erreur_connexion_mysql' => 'Errore di connessione SQL',
	'avis_espace_interdit' => '<b>Area vietata</b> <div>SPIP è già installato.</div>',
	'avis_lecture_noms_bases_1' => 'Il programma di installazione non ha potuto leggere i nomi dei database installati nel server.',
	'avis_lecture_noms_bases_2' => 'Nessun database è disponibile, o la funzione che permette di accedere alla lista database è
disattivata per motivi sicurezza (verifica con l’amministratrice di sistema).',
	'avis_lecture_noms_bases_3' => 'Nel secondo caso, è probabile che un database con il tuo nome di login sia utilizzabile:',
	'avis_non_acces_page' => 'Non hai accesso a questa pagina.',
	'avis_operation_echec' => 'L’operazione è fallita.',
	'avis_operation_impossible' => 'Operazione impossibile',
	'avis_suppression_base' => 'ATTENZIONE, la cancellazione dei dati è irreversibile',

	// B
	'bouton_acces_ldap' => 'Aggiungi l’accesso a LDAP',
	'bouton_ajouter' => 'Aggiungi',
	'bouton_annuler' => 'Annulla',
	'bouton_cache_activer' => 'Riattivare la cache',
	'bouton_cache_desactiver' => 'Disattivare temporaneamente la cache',
	'bouton_demande_publication' => 'Chiedi la pubblicazione di questo articolo',
	'bouton_desactive_tout' => 'Disattiva tutto',
	'bouton_desinstaller' => 'Disinstalla',
	'bouton_effacer_tout' => 'Cancella TUTTO',
	'bouton_envoyer_message' => 'Messaggio definitivo: Invia',
	'bouton_fermer' => 'Chiudere',
	'bouton_mettre_a_jour_base' => 'Aggiornare il database',
	'bouton_modifier' => 'Modifica',
	'bouton_radio_afficher' => 'Visualizza',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Comparire nell’elenco delle redattrici collegate',
	'bouton_radio_envoi_annonces_adresse' => 'Invia gli annunci all’indirizzo:',
	'bouton_radio_envoi_liste_nouveautes' => 'Invia l’elenco delle novità',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non comparire nell’elenco delle redattrici collegate ',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Non inviare annunci editoriali ',
	'bouton_redirection' => 'REINDIRIZZAMENTO',
	'bouton_relancer_installation' => 'Rilanciare l’installazione',
	'bouton_suivant' => 'Avanti',
	'bouton_tenter_recuperation' => 'Tentare un ripristino',
	'bouton_test_proxy' => 'Testare il proxy',
	'bouton_vider_cache' => 'Svuota la cache',

	// C
	'cache_modifiable_webmestre' => 'Questo parametro può essere modificato dalla webmistress del sito.',
	'calendrier_synchro' => 'Se si utilizza un programma di agenda compatibile con <b>iCal</b>, è possibile sincronizzare i dati con le informazioni di questo sito',
	'config_activer_champs' => 'Attiva i campi seguenti',
	'config_choix_base_sup' => 'indicare un database su questo server',
	'config_erreur_base_sup' => 'SPIP non ha accesso all’elenco dei database accessibili ',
	'config_info_base_sup' => 'Se si hanno altri database da interrogare attraverso SPIP, con il proprio server SQL o altro, il form sottostante permette di dichiararli. Se si lasciano alcuni campi vuoti verranno utilizzati i dati della connessione al database principale.',
	'config_info_base_sup_disponibles' => 'Database supplementari già dichiarati:',
	'config_info_enregistree' => 'La nuova configurazione è stata registrata',
	'config_info_logos' => 'Ogni elemento del sito può avere un logo, come pure un « logo per il roll-over »',
	'config_info_logos_utiliser' => 'Utilizza i logo',
	'config_info_logos_utiliser_non' => 'Non utilizzare i logo',
	'config_info_logos_utiliser_survol' => 'Utilizzare i logo di roll-over',
	'config_info_logos_utiliser_survol_non' => 'Non utilizzare i logo di roll-over',
	'config_info_redirection' => 'Attivando questa opzione è possibile creare degli articoli virtuali, semplici riferimenti di articoli pubblicati su altri siti o al di fuori di SPIP.',
	'config_redirection' => 'Articoli virtuali',
	'config_titre_base_sup' => 'Dichiarazione di un database supplementare',
	'config_titre_base_sup_choix' => 'Scegliere un database supplementare',
	'connexion_ldap' => 'Connessione:',
	'creer_et_associer_un_auteur' => 'Creare ed associare un’autrice',

	// D
	'date_mot_heures' => 'ore',

	// E
	'ecran_securite' => ' + schermo di sicurezza @version@', # RELIRE
	'email' => 'email',
	'email_2' => 'email:',
	'en_savoir_plus' => 'Ulteriori informazioni', # RELIRE
	'entree_adresse_annuaire' => 'Indirizzo della rubrica',
	'entree_adresse_email' => 'Il tuo indirizzo email',
	'entree_adresse_email_2' => 'Indirizzo email',
	'entree_base_donnee_1' => 'Indirizzo del database',
	'entree_base_donnee_2' => '(Spesso questo indirizzo coincide con quello dell’intero sito, qualche volta corrisponde a "localhost", altre volte invece non è necessario specificarlo.)',
	'entree_biographie' => 'La tua biografia in breve.',
	'entree_chemin_acces' => '<b>Inserire</b> il percorso d’accesso:',
	'entree_cle_pgp' => 'Chiave PGP',
	'entree_cle_pgp_2' => 'Autenticazione', # RELIRE
	'entree_contenu_rubrique' => '(Contenuto della rubrica in qualche parola)',
	'entree_identifiants_connexion' => 'Identificativo di connessione...',
	'entree_identifiants_connexion_2' => 'Identificativo', # RELIRE
	'entree_informations_connexion_ldap' => 'Inserisci in questo form gli estremi per la connessione alla tua rubrica LDAP.
Se non conosci queste informazioni, richiedile all’amministratrice del sistema o della rete.',
	'entree_infos_perso' => 'Chi sei?',
	'entree_infos_perso_2' => 'Chi è l’autrice ?',
	'entree_interieur_rubrique' => 'All’interno della rubrica:',
	'entree_liens_sites' => '<b>Link ipertestuale</b> (riferimento, sito da visitare...)',
	'entree_login' => 'Login',
	'entree_login_connexion_1' => 'Il login di connessione',
	'entree_login_connexion_2' => '(Corrisponde a volte al login d’accesso via FTP; in alcuni casi non occorre specificare nulla)',
	'entree_mot_passe' => 'Password',
	'entree_mot_passe_1' => 'La password di connessione',
	'entree_mot_passe_2' => '(Corrisponde a volte alla password d’accesso via FTP; in alcuni casi non occorre specificare nulla)',
	'entree_nom_fichier' => 'Inserire il nome del file @texte_compresse@:',
	'entree_nom_pseudo' => 'Nome o pseudonimo',
	'entree_nom_pseudo_1' => '(Nome o pseudonimo)',
	'entree_nom_pseudo_2' => 'Nome o pseudonimo',
	'entree_nom_site' => 'Nome del tuo sito',
	'entree_nom_site_2' => 'Nome del sito dell’autrice', # RELIRE
	'entree_nouveau_passe' => 'Nuova password',
	'entree_passe_ldap' => 'Password',
	'entree_port_annuaire' => 'Il numero di porta della rubrica',
	'entree_signature' => 'Firma',
	'entree_titre_obligatoire' => '<b>Titolo</b> [Obbligatorio]<br />',
	'entree_url' => 'Indirizzo (URL) del sito',
	'entree_url_2' => 'Indirizzo (URL) del sito',
	'erreur_connect_deja_existant' => 'Esiste già un server con questo nome', # RELIRE
	'erreur_email_deja_existant' => 'Questo indirizzo email è già registrato',
	'erreur_nom_connect_incorrect' => 'Questo nome non è autorizzato', # RELIRE
	'erreur_plugin_desinstalation_echouee' => 'La disinstallazione del plug in è fallita. E’ comunque possibile disattivarlo.', # RELIRE
	'erreur_plugin_fichier_absent' => 'File non presente',
	'erreur_plugin_fichier_def_absent' => 'File di definizioni non presente',
	'erreur_plugin_nom_fonction_interdit' => 'Nome di funzione non possibile',
	'erreur_plugin_nom_manquant' => 'Nome del plugin mancante',
	'erreur_plugin_prefix_manquant' => 'Spazio per il nome del plugin non definito',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; mancante nel file di definizione',
	'erreur_plugin_version_manquant' => 'Versione del plugin mancante',

	// H
	'htaccess_a_simuler' => 'Attenzione: la configurazione del vostro server HTTP non tiene conto dei file @htaccess@. Per poter mettere in sicurezza bisognerà modificare la configurazione di questo punto, oppure sarà necessario che i parametri fissi @constantes@ (definiti nel file le_mie_opzioni.php) abbiano i valore dei registri diversi da @document_root@.', # RELIRE

	// I
	'ical_info1' => 'Questa pagina elenca diversi metodi per rimanere in contatto con le varie attività del sito.',
	'ical_info2' => 'Per ulteriori informazioni su tutte queste tecniche, non esitate a consultare <a href="@spipnet@">la documentazione di SPIP</a>.',
	'ical_info_calendrier' => 'Sono disponibili due calendari. Il primo è una mappa del sito che annuncia tutti gli articoli pubblicati. Il secondo contiene gli annunci editoriali e gli ultimi messaggi privati: è un’area riservata, mediante identificativo personale, che è possibile modificare in qualsiasi momento rinnovando la password personale.',
	'ical_methode_http' => 'Download',
	'ical_methode_webcal' => 'Sincronizzazione (webcal://)',
	'ical_texte_js' => 'Una linea in javascript permette di visualizzare, con molta semplicità e su qualsiasi tipo di sito, gli articoli recenti pubblicati su questo sito.',
	'ical_texte_prive' => 'Questo calendario, ad uso strettamente privato, dà informazioni sull’attività redazionale privata di questo sito (impegni e appuntamenti personali, articoli e brevi proposti...).',
	'ical_texte_public' => 'Questo calendario permette di monitorare l’attività pubblica del sito (articoli e brevi pubblicati).',
	'ical_texte_rss' => 'È possibile mettere in syndication le novità di questo sito con qualsiasi lettore di file in formato XML/RSS (Rich Site Summary). Questo è il medesimo formato che permette a SPIP di leggere le novità pubblicate su altri siti che utilizzano un formato di scambio compatibile.',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'File di syndication',
	'icone_activer_cookie' => 'Attiva il cookie di corrispondenza',
	'icone_activite' => 'Attività',
	'icone_admin_plugin' => 'Gestione dei plugin',
	'icone_afficher_auteurs' => 'Pubblica le autrici',
	'icone_afficher_visiteurs' => 'Pubblica i visitatori',
	'icone_arret_discussion' => 'Non partecipare più a questa discussione',
	'icone_calendrier' => 'Calendario',
	'icone_creer_auteur' => 'Crea una nuova autrice ed associala a questo articolo',
	'icone_creer_mot_cle' => 'Crea una nuova parola chiave e collegala a questo articolo',
	'icone_creer_rubrique_2' => 'Crea una nuova rubrica',
	'icone_ma_langue' => 'La mia lingua',
	'icone_mes_infos' => 'Le mie informazioni',
	'icone_modifier_article' => 'Modifica l’articolo',
	'icone_modifier_rubrique' => 'Modifica la rubrica',
	'icone_relancer_signataire' => 'Rilanciare il firmatario',
	'icone_retour' => 'Indietro',
	'icone_retour_article' => 'Torna all’articolo',
	'icone_supprimer_cookie' => 'Elimina il cookie di corrispondenza',
	'icone_supprimer_rubrique' => 'Elimina la rubrica',
	'icone_supprimer_signature' => 'Cancella l’adesione',
	'icone_valider_signature' => 'Conferma l’adesione',
	'image_administrer_rubrique' => 'Puoi amministrare questa rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 articolo',
	'info_activer_cookie' => 'Se vuoi puoi attivare un <b>cookie di corrispondenza</b>, che ti permetterà
di passare facilmente dal sito pubblico all’interfaccia privata.',
	'info_administrateur' => 'Amministratrice',
	'info_administrateur_1' => 'Amministratrice',
	'info_administrateur_2' => 'del sito (<i>da utilizzare con prudenza</i>)',
	'info_administrateur_site_01' => 'Se sei amministratrice del sito,',
	'info_administrateur_site_02' => 'clicca qui',
	'info_administrateurs' => 'Amministratrici',
	'info_administrer_rubrique' => 'Puoi amministrare questa rubrica',
	'info_adresse' => 'all’indirizzo:',
	'info_adresse_url' => 'Indirizzo (URL) del sito pubblico',
	'info_aide_en_ligne' => 'Guida in linea SPIP',
	'info_ajout_image' => 'Quando aggiungi delle immagini come documenti allegati ad un articolo,
SPIP può creare  delle thumbnail (miniature) delle
immagini inserite. Ciò permette ad esempio di creare in automatico una galleria di immagini o un portfolio.',
	'info_ajouter_rubrique' => 'Aggiungi un’altra rubrica da amministrare:',
	'info_annonce_nouveautes' => 'Annuncio delle novità',
	'info_article' => 'articolo',
	'info_article_2' => 'articoli',
	'info_article_a_paraitre' => 'Gli articoli postdatati da pubblicare',
	'info_articles_02' => 'articoli',
	'info_articles_2' => 'Articoli',
	'info_articles_auteur' => 'Articoli di questo autore',
	'info_articles_trouves' => 'Articoli trovati',
	'info_attente_validation' => 'I tuoi articoli in attesa di convalida',
	'info_aujourdhui' => 'oggi: ',
	'info_auteurs' => 'Le autrici',
	'info_auteurs_par_tri' => 'Autrici@partri@',
	'info_auteurs_trouves' => 'Autrici trovate',
	'info_authentification_externe' => 'Autenticazione esterna',
	'info_avertissement' => 'Avvertimento',
	'info_barre_outils' => 'con la barra degli strumenti?',
	'info_base_installee' => 'La struttura del vostro database è installata.',
	'info_chapeau' => 'Introduzione',
	'info_chapeau_2' => 'Introduzione:',
	'info_chemin_acces_1' => 'Opzioni: <b>Percorso d’accesso ai dati nell’elenco</b>',
	'info_chemin_acces_2' => 'È necessario specificare il percorso per accedere ai dati nell’elenco. Questa informazione è indispensabile al fine di leggere i profili utente in esso contenuti.',
	'info_chemin_acces_annuaire' => 'Opzioni: <b>Percorso d’accesso ai dati nell’elenco',
	'info_choix_base' => 'Terza fase: ',
	'info_classement_1' => '<sup>o</sup> su @liste@',
	'info_classement_2' => '<sup>o</sup> su @liste@',
	'info_code_acces' => 'Non dimenticare i tuoi codici d’accesso!',
	'info_config_suivi' => 'Se questo indirizzo corrisponde a una mailing-list, è possibile indicare qui sotto l’indirizzo al quale i partecipanti del sito possono iscriversi. Questo indirizzo può essere una URL (per esempio la pagina di iscrizione via Web alla lista), oppure un indirizzo email che contiene un Oggetto specifico (per esempio: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'È possibile abbonarsi alla mailing-list di questo sito. Verranno spedite per email le notifiche degli articoli e delle brevi proposte per la pubblicazione.',
	'info_confirmer_passe' => 'Conferma la nuova password:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Attenzione, i campi seguenti sono già stati modificati. Quindi le vostre modifiche su questi campi non sono state registrate.',
	'info_conflit_edition_differences' => 'Differenze:',
	'info_conflit_edition_version_enregistree' => 'La versione registrata:',
	'info_conflit_edition_votre_version' => 'La tua versione:',
	'info_connexion_base' => 'Prova di connessione al database',
	'info_connexion_base_donnee' => 'Connessione al proprio database',
	'info_connexion_ldap_ok' => 'La connessione LDAP è riuscita.</b><p> È possibile passare alla fase successiva.</p>',
	'info_connexion_mysql' => 'La connessione a SQL',
	'info_connexion_ok' => 'La connessione è riuscita.',
	'info_contact' => 'Contatti',
	'info_contenu_articles' => 'Contentuto degli articoli',
	'info_creation_paragraphe' => 'Per creare dei paragrafi indipendenti, lasciare delle righe vuote.', # RELIRE
	'info_creation_rubrique' => 'Prima di poter scrivere degli articoli, <br />devi creare almeno una rubrica.<br />',
	'info_creation_tables' => 'Creazione delle tabelle nel database',
	'info_creer_base' => '<b>Creare</b> un nuovo database:',
	'info_dans_rubrique' => 'Nella rubrica:',
	'info_date_publication_anterieure' => 'Data di redazione anteriore:',
	'info_date_referencement' => 'DATA DI INSERIMENTO IN REPERTORIO DI QUESTO SITO:',
	'info_derniere_etape' => 'Finito!',
	'info_descriptif' => 'Descrizione:',
	'info_desinstaller_plugin' => 'elimina i dati e disattiva il plug-in',
	'info_discussion_cours' => 'Discussioni in corso',
	'info_ecrire_article' => 'Prima di poter scrivere degli articoli, devi creare almeno una rubrica.',
	'info_email_envoi' => 'Indirizzo email del mittente (opzionale)',
	'info_email_envoi_txt' => 'Indicare qui l’indirizzo da utilizzare per l’invio degli email (come impostazione predefinita l’indirizzo del destinatario sarà utilizzato come indirizzo del mittente):',
	'info_email_webmestre' => 'Indirizzo email della webmistress', # RELIRE
	'info_envoi_email_automatique' => 'Invio di email automatico',
	'info_envoyer_maintenant' => 'Invia adesso',
	'info_etape_suivante' => 'Passare alla fase successiva',
	'info_etape_suivante_1' => 'Puoi passare alla fase successiva.',
	'info_etape_suivante_2' => 'Puoi passare alla fase successiva.',
	'info_exportation_base' => 'esportazione del database verso @archive@',
	'info_facilite_suivi_activite' => 'Al fine di facilitare il monitoraggio
dell’attività editoriale del sito, SPIP può far pervenire via email,
per esempio ad una mailing-list delle redattrici, l’annuncio delle domande di
pubblicazione e di convalida degli articoli.', # MODIF
	'info_fichiers_authent' => 'File d’autenticazione ".htpasswd"',
	'info_forums_abo_invites' => 'Il sito comprende dei forum accessibili solo a utenti registrate. Nel sito pubblico è quindi presente una pagina d’iscrizione.',
	'info_gauche_admin_tech' => '<b>Questa pagina è accessibile solo alle responsabili del sito.</b><p> Permette l’accesso alle diverse funzioni di manutenzione tecnica. Alcune di esse richiedono una procedura di identificazione specifica, tramite accesso FTP.</p>', # RELIRE
	'info_gauche_admin_vider' => '<b>Questa pagina è accessibile solo alle responsabili del sito.</b><p> Permette l’accesso alle diverse funzioni di manutenzione tecnica. Alcune di esse richiedono una procedura di identificazione specifica, tramite accesso FTP.</p>', # RELIRE
	'info_gauche_auteurs' => 'Elenco di tutte le autrici del sito.
Il loro status è indicato dal colore dell’icona (redattrice = giallo; amministratrice = verde).',
	'info_gauche_auteurs_exterieurs' => 'Le autrici esterne, senza accesso al sito, sono indicate da un’icona blu;
                le autrici eliminate sono indicate da un’icona grigia.', # RELIRE
	'info_gauche_messagerie' => 'Il sistema di messaggistica permette di scambiare dei messaggi tra redattrici, di conservare dei memo (promemoria ad uso personale) o di pubblicare degli annunci nel pannello di controllo dell’area riservata (se sei amministratrice).',
	'info_gauche_statistiques_referers' => 'Questa pagina presenta un elenco dei siti che contengono link verso il tuo (<i>referrer</i>). Questo elenco è valido però solo per oggi essendo azzerato ogni 24 ore.',
	'info_gauche_visiteurs_enregistres' => 'Trovi qui i visitatori registrati allo spazio
pubblico del sito (forum su abbonamento).',
	'info_generation_miniatures_images' => 'Generazione di thumbnail di immagini',
	'info_hebergeur_desactiver_envoi_email' => 'Alcuni hoster disattivano l’invio automatico di email
dai loro server. In questo caso, le funzionalità di SPIP di seguito riportate non funzioneranno.',
	'info_hier' => 'ieri:',
	'info_identification_publique' => 'La tua identità pubblica...',
	'info_image_process' => 'Seleziona il metodo migliore per la creazione delle anteprime cliccando sull’immagine corrispondente.',
	'info_image_process2' => 'Se non appare alcuna immagine, ciò significa che la configurazione del server non permette l’uso di tali funzioni. Se si desidera utilizzarle, contattate la responsabile tecnica chiedendo delle estensioni "GD" o "Imagick".', # RELIRE
	'info_images_auto' => 'Immagini elaborate automaticamente',
	'info_informations_personnelles' => 'Informazioni personali',
	'info_inscription_automatique' => 'Iscrizione automatica di nuove redattrici',
	'info_jeu_caractere' => 'Set di caratteri del sito',
	'info_jours' => 'giorni',
	'info_laisser_champs_vides' => 'lasciare questi campi vuoti)',
	'info_langues' => 'Lingua del sito',
	'info_ldap_ok' => 'L’autenticazione LDAP è installata.',
	'info_lien_hypertexte' => 'Link ipertestuale:',
	'info_liste_redacteurs_connectes' => 'Elenco delle redattrici collegate',
	'info_login_existant' => 'Questo login esiste già.',
	'info_login_trop_court' => 'Login troppo corto.',
	'info_logos' => 'I logo',
	'info_maximum' => 'massimo:',
	'info_meme_rubrique' => 'Nella stessa rubrica',
	'info_message_en_redaction' => 'I tuoi messaggi in corso di redazione',
	'info_message_technique' => 'Messaggio tecnico:',
	'info_messagerie_interne' => 'Sistema di messaggistica interna',
	'info_mise_a_niveau_base' => 'aggiornamento del database SQL',
	'info_mise_a_niveau_base_2' => '{{Attenzione!}} È stata installata una versione
dei file di SPIP {precedente} rispetto a quella che era in uso per questo sito:
le informazioni contenute nel database sono probabilmente andate perse.<br />{{Reinstallare i file di SPIP.}}',
	'info_modifier_auteur' => 'Modifica l’autrice:',
	'info_modifier_rubrique' => 'Modifica la rubrica:',
	'info_modifier_titre' => 'Modifica: @titre@',
	'info_mon_site_spip' => 'Il mio sito SPIP',
	'info_moyenne' => 'media: ',
	'info_multi_cet_article' => 'Lingua di questo articolo:',
	'info_multi_langues_choisies' => 'Selezionare di seguito le lingue disponibili per le redattrici del sito.
  Le lingue già utilizzate nel sito (visualizzate per prime) non possono essere disattivate.',
	'info_multi_secteurs' => '... solo per le rubriche collocate nella {root} del sito?',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome del destinatario',
	'info_nom_site' => 'Nome del tuo sito',
	'info_nombre_articles' => '@nb_articles@ articoli,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubriche,',
	'info_nombre_sites' => '@nb_sites@ siti, ',
	'info_non_deplacer' => 'Non spostare...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP può inviare regolarmente annunci sulle ultime novità del sito
(articoli e brevi recentemente pubblicati).',
	'info_non_envoi_liste_nouveautes' => 'Non inviare l’elenco delle novità',
	'info_non_modifiable' => 'non può essere modificato',
	'info_non_suppression_mot_cle' => 'non voglio cancellare questa parola chiave.',
	'info_notes' => 'Note',
	'info_nouvel_article' => 'Nuovo articolo',
	'info_nouvelle_traduction' => 'Nuova traduzione:',
	'info_numero_article' => 'ARTICOLO NUMERO:',
	'info_obligatoire_02' => '(obbligatorio)', # MODIF
	'info_option_accepter_visiteurs' => 'Accetta l’iscrizione di utenti del sito pubblico',
	'info_option_ne_pas_accepter_visiteurs' => 'Rifiuta l’iscrizione di utenti',
	'info_options_avancees' => 'OPZIONE AVANZATA',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina riservata',
	'info_par_nom' => 'per nome',
	'info_par_nombre_article' => 'per numero di articoli',
	'info_par_statut' => 'per status',
	'info_par_tri' => '’(per @tri@)’',
	'info_passe_trop_court' => 'Password troppo corta.',
	'info_passes_identiques' => 'Le due password non sono uguali.',
	'info_plus_cinq_car' => 'più di 5 caratteri',
	'info_plus_cinq_car_2' => '(Più di 5 caratteri)',
	'info_plus_trois_car' => '(Più di 3 caratteri)',
	'info_popularite' => 'popolarità: @popularite@; visite: @visites@',
	'info_post_scriptum' => 'Post Scriptum',
	'info_post_scriptum_2' => 'Post Scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'È possibile visualizzare un’anteprima del sito comprendente anche gli articoli e le brevi "proposti" per la pubblicazione. Questa funzionalità può essere disattivata, consentita solo alle amministratrici o a tutte le redattrici.', # MODIF
	'info_procedez_par_etape' => 'procedere passo dopo passo',
	'info_procedure_maj_version' => 'è necessario avviare la procedura di aggiornamento per adattare
il database alla nuova versione di SPIP.',
	'info_proxy_ok' => 'Test del proxy riuscito.',
	'info_ps' => 'P.S.',
	'info_publier' => 'pubblicare',
	'info_publies' => 'I tuoi articoli pubblicati',
	'info_question_accepter_visiteurs' => 'I modelli di pagina del sito prevedono la registrazione di utenti senza accesso all’area riservata. Attivare la seguente funzionalità:',
	'info_question_inscription_nouveaux_redacteurs' => 'Accettate le iscrizioni di nuove redattrici
direttamente dal sito pubblico? In questo caso, chi visita il sito potrà iscriversi
grazie ad un modulo automatizzato e potrà accedere all’area riservata per proporre i propri articoli.
<div class="notice">Durante la fase d’iscrizione,
le utenti ricevono automaticamente un’email
che fornisce loro i codici d’accesso al sito privato. Alcuni
host disattivano l’invio di email dai
propri server: in questo caso, l’iscrizione automatica è
impossibile.', # RELIRE
	'info_qui_edite' => '@nom_auteur_modif@ ha lavorato su questo contenuto @date_diff@ minuti fa',
	'info_racine_site' => 'Root del sito',
	'info_recharger_page' => 'Aggiorna questa pagina fra qualche istante.',
	'info_recherche_auteur_zero' => 'Nessun risultato per "@cherche_auteur@".',
	'info_recommencer' => 'Ricomincia.',
	'info_redacteur_1' => 'Redattori',
	'info_redacteur_2' => 'avendo accesso allo spazio privato (<i>raccommandato</i>)',
	'info_redacteurs' => 'Redattrici',
	'info_redaction_en_cours' => 'IN CORSO DI REDAZIONE',
	'info_redirection' => 'Reindirizzamento',
	'info_refuses' => 'I tuoi articoli rifiutati',
	'info_reglage_ldap' => 'Opzioni: <b>Parametri per l’importazione LDAP</b>',
	'info_renvoi_article' => '<b>Reindirizzamento.</b> Quest’articolo rimanda alla pagina:',
	'info_reserve_admin' => 'Solo le amministratrici possono modificare quest’indirizzo.',
	'info_restreindre_rubrique' => 'Limita la facoltà di gestione alla rubrica:',
	'info_resultat_recherche' => 'Risultati della ricerca:',
	'info_rubriques' => 'Rubriche',
	'info_rubriques_02' => 'rubriche',
	'info_rubriques_trouvees' => 'Rubriche trovate',
	'info_sans_titre' => 'Senza titolo',
	'info_selection_chemin_acces' => '<b>Seleziona</b> qui sotto il percorso d’accesso nell’elenco:',
	'info_signatures' => 'firme',
	'info_site' => 'Sito',
	'info_site_2' => 'sito: ',
	'info_site_min' => 'sito',
	'info_site_reference_2' => 'Sito repertoriato',
	'info_site_web' => 'Sito Web :',
	'info_sites' => 'siti',
	'info_sites_lies_mot' => 'I siti in repertorio legati a questa parola chiave',
	'info_sites_proxy' => 'Utilizza un proxy',
	'info_sites_trouves' => 'Siti trovati',
	'info_sous_titre' => 'Sottotitolo:',
	'info_statut_administrateur' => 'Amministratrice',
	'info_statut_auteur' => 'Status di questa autrice:',
	'info_statut_auteur_a_confirmer' => 'Iscrizione da confermare',
	'info_statut_auteur_autre' => 'Altro stato:',
	'info_statut_redacteur' => 'Redattrice',
	'info_statut_utilisateurs_1' => 'Status predefinito delle utenti importate',
	'info_statut_utilisateurs_2' => 'Scegli lo status da attribuire alle personne presenti nell’elenco LDAP quando si collegano per la prima volta. Potrai poi modificare questa impostazione per ogni singola autrice.',
	'info_suivi_activite' => 'Monitoraggio dell’attività editoriale',
	'info_surtitre' => 'Occhiello:',
	'info_syndication_integrale_1' => 'Il tuo sito propone dei file di  syndication (vedi « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Si desidera trasmettere gli articoli in versione integrale oppure in versione riassunta di un centinaio di caratteri?',
	'info_table_prefix' => 'È possibile modificare il prefisso del nome delle tabelle del database (cosa indispensabile se si desidera installare più siti usando il medesimo database). Questo prefisso si deve scrivere usando esclusivamente lettere minuscole, prive di accenti e senza alcuno spazio.',
	'info_taille_maximale_images' => 'SPIP testerà la dimensione massima delle immagini che può manipolare (in milioni di pixel).<br /> Le immagini di dimensione maggiore non saranno ridotte.',
	'info_taille_maximale_vignette' => 'Dimensione massima delle immagini create dal sistema:',
	'info_terminer_installation' => 'Puoi ora terminare la procedura d’installazione standard.',
	'info_texte' => 'Testo',
	'info_texte_explicatif' => 'Testo esplicativo',
	'info_texte_long' => '(il testo è lungo: è quindi visualizzato in più sezioni che verranno riunificate dopo la convalida)',
	'info_texte_message' => 'Testo del messaggio',
	'info_texte_message_02' => 'Testo del messaggio',
	'info_titre' => 'Titolo:',
	'info_total' => 'totale: ',
	'info_tous_articles_en_redaction' => 'Tutti gli articoli in corso di redazione',
	'info_tous_articles_presents' => 'Tutti gli articoli pubblicati in questa rubrica',
	'info_tous_les' => 'tutti i:',
	'info_tout_site' => 'Tutto il sito',
	'info_tout_site2' => 'L’articolo non è stato tradotto in questa lingua.',
	'info_tout_site3' => 'L’articolo è stato tradotto in questa lingua, ma sono state effettuate alcune modifiche all’articolo di riferimento. La traduzione deve quindi essere aggiornata.',
	'info_tout_site4' => 'L’articolo è stato tradotto in questa lingua e la traduzione è aggiornata.',
	'info_tout_site5' => 'Articolo originale.',
	'info_tout_site6' => '<b>Attenzione:</b> solo gli articoli originali vengono visualizzati.
Le traduzioni sono associate all’originale,
 in un colore che indica il loro stato:',
	'info_travail_colaboratif' => 'Lavoro di collaborazione sugli articoli',
	'info_un_article' => 'un articolo, ',
	'info_un_site' => 'un sito, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Link ipertestuale:',
	'info_utilisation_spip' => 'Puoi ora cominciare ad utilizzare il sistema di pubblicazione assistita...',
	'info_visites_par_mois' => 'Visualizzazione per mese:',
	'info_visiteur_1' => 'Visitatori',
	'info_visiteur_2' => 'del sito pubblico',
	'info_visiteurs' => 'Visitatori',
	'info_visiteurs_02' => 'Visitatori del sito pubblico',
	'install_adresse_base_hebergeur' => 'Indirizzo del database attribuito dal provider',
	'install_echec_annonce' => 'L’installazione potrebbe fallire oppure causare problemi di funzionalità al sito...',
	'install_extension_mbstring' => 'SPIP non funziona con:',
	'install_extension_php_obligatoire' => 'SPIP esige l’estensione php:',
	'install_login_base_hebergeur' => 'Login di connessione attribuito dal provider',
	'install_nom_base_hebergeur' => 'Nome del database attribuito dal provider:',
	'install_pas_table' => 'Database attualmente senza tabelle',
	'install_pass_base_hebergeur' => 'Password di connessione attribuito dal provider',
	'install_php_version' => 'PHP versione @version@ insufficiente (minimo = @minimum@)',
	'install_select_langue' => 'Seleziona una lingua e poi clicca sul bottone « Avanti » per lanciare la procedura di installazione.',
	'install_select_type_db' => 'Indicare il tipo di database:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Server del database attribuito dall’hoster',
	'install_table_prefix_hebergeur' => 'Prefisso della tabella attribuito dal provider:',
	'install_tables_base' => 'Tabelle del database',
	'install_types_db_connus' => 'SPIP può utilizzare <b>MySQL</b> (il più diffuso) e <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Il supporto <b>PostgreSQL</b> viene proposto a titolo sperimentale', # RELIRE
	'intem_redacteur' => 'redattrice',
	'intitule_licence' => 'Licenza',
	'item_accepter_inscriptions' => 'Accetta le iscrizioni',
	'item_activer_messages_avertissement' => 'Attiva i messaggi d’avvertimento',
	'item_administrateur_2' => 'amministratrice',
	'item_afficher_calendrier' => 'Pubblica nel calendario',
	'item_autoriser_syndication_integrale' => 'Diffondere la versione integrale degli articoli nei file di syndication',
	'item_choix_administrateurs' => 'le amministratrici',
	'item_choix_generation_miniature' => 'Genera automaticamente le thumbnail delle immagini.',
	'item_choix_non_generation_miniature' => 'Non creare le thumbnail delle immagini.',
	'item_choix_redacteurs' => 'le redattrici',
	'item_choix_visiteurs' => 'i visitatori del sito pubblico',
	'item_creer_fichiers_authent' => 'Crea i file .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Attiva la messaggistica e l’agenda',
	'item_mots_cles_association_articles' => 'agli articoli',
	'item_mots_cles_association_rubriques' => 'alle rubriche',
	'item_mots_cles_association_sites' => 'ai siti repertoriati o in syndication.',
	'item_non' => 'No',
	'item_non_accepter_inscriptions' => 'Non accettare le iscrizioni',
	'item_non_activer_messages_avertissement' => 'Nessun messaggio d’avvertimento',
	'item_non_afficher_calendrier' => 'Non pubblicare nel calendario',
	'item_non_autoriser_syndication_integrale' => 'Diffondere solo un riassunto',
	'item_non_creer_fichiers_authent' => 'Non creare questi file',
	'item_non_messagerie_agenda' => 'Disattiva la messaggistica e l’agenda',
	'item_non_publier_articles' => 'Non pubblicare gli articoli prima della data impostata.',
	'item_nouvel_auteur' => 'Nuova autrice',
	'item_nouvelle_rubrique' => 'Nuova rubrica',
	'item_oui' => 'Sì',
	'item_publier_articles' => 'Pubblica gli articoli indipendentemente dalla data impostata.',
	'item_reponse_article' => 'Risposta all’articolo ',
	'item_visiteur' => 'visitatore',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Aggiungi questa autrice',
	'lien_email' => 'email',
	'lien_nom_site' => 'NOME DEL SITO:',
	'lien_retirer_auteur' => 'Rimuovere l’autrice',
	'lien_site' => 'sito',
	'lien_tout_deplier' => 'Espandi',
	'lien_tout_replier' => 'Richiudi',
	'lien_tout_supprimer' => 'Eliminare tutto',
	'lien_trier_nom' => 'Ordina per nome',
	'lien_trier_nombre_articles' => 'Ordina per numero di articoli',
	'lien_trier_statut' => 'Ordina per status',
	'lien_voir_en_ligne' => 'VEDI ON LINE:',
	'logo_article' => 'Logo dell’articolo',
	'logo_auteur' => 'Logo dell’autrice',
	'logo_rubrique' => 'Logo della rubrica',
	'logo_site' => 'Logo di questo sito',
	'logo_standard_rubrique' => 'Logo standard delle rubriche',
	'logo_survol' => 'Logo rollover', # RELIRE

	// M
	'menu_aide_installation_choix_base' => 'Scegliere il database',
	'module_fichier_langue' => 'File lingua',
	'module_raccourci' => 'Scorciatoia',
	'module_texte_affiche' => 'Testo visualizzato',
	'module_texte_explicatif' => 'È possibile inserire le scorciatoie nel modello di layout del proprio sito pubblico. Queste verranno tradotte automaticamente nelle diverse lingue (se esiste già un file lingua).',
	'module_texte_traduction' => 'Il file lingua «@module@» è disponibile in:',
	'mois_non_connu' => 'sconosciuto',

	// O
	'onglet_contenu' => 'Contenuto',
	'onglet_declarer_une_autre_base' => 'Dichiarare un altro database',
	'onglet_discuter' => 'Discuti',
	'onglet_interactivite' => 'Interattività',
	'onglet_proprietes' => 'Proprietà',
	'onglet_repartition_actuelle' => 'attualmente',
	'onglet_sous_rubriques' => 'Sotto-rubriche',

	// P
	'page_pas_proxy' => 'Questa pagina non deve passare attraverso il proxy',
	'pas_de_proxy_pour' => 'Se necessario, indicare i server o i domini per i quali non si deve applicare questo proxy (per esempio: @exemple@)',
	'plugin_charge_paquet' => 'Caricamento del pacchetto @name@',
	'plugin_erreur_charger' => 'errore: impossibile caricare @zip@',
	'plugin_erreur_droit1' => 'La cartella <code>@dest@</code> non ha i permessi di scrittura.',
	'plugin_erreur_droit2' => 'Verificare i diritti su questa cartella (e, se necessario, crearla), o installare i file tramite FTP.',
	'plugin_erreur_zip' => 'fallimento pclzip: errore @status@',
	'plugin_etat_developpement' => 'in corso di sviluppo',
	'plugin_etat_experimental' => 'sperimentale',
	'plugin_etat_stable' => 'stabile',
	'plugin_etat_test' => 'in prova',
	'plugin_impossible_activer' => 'Impossibile attivare il plug-in @plugin@',
	'plugin_info_automatique1' => 'Se si desidera autorizzare l’installazione automatica dei plug-in è necessario: ',
	'plugin_info_automatique2' => 'creare una cartella <code>@rep@</code>;',
	'plugin_info_automatique3' => 'verificare che il server sia autorizzato a scrivere in questa cartella.',
	'plugin_info_automatique_creer' => 'da creare alla radice del sito.',
	'plugin_info_automatique_exemples' => 'esempi:',
	'plugin_info_automatique_ftp' => 'È possibile installare plug-in tramite FTP, nella cartella <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Alcuni plug-in richiedono anche di poter trasferire dei file nella cartella <code>lib/</code>, da creare (se necessario) alla radice del sito.',
	'plugin_info_automatique_liste' => 'Gli elenchi dei plug-in:',
	'plugin_info_automatique_liste_officielle' => 'i plug-in ufficiali',
	'plugin_info_automatique_liste_update' => 'Aggiornare gli elenchi',
	'plugin_info_automatique_ou' => 'oppure...',
	'plugin_info_automatique_select' => 'Selezionata un plug-in qui sotto: SPIP lo scaricherà e lo installerà nella cartella <code>@rep@</code>; se questo plug-in è già presente verrà aggiornato.',
	'plugin_info_telecharger' => 'da scaricare da @url@ e da installare in @rep@',
	'plugin_librairies_installees' => 'Librerie installate',
	'plugin_necessite_lib' => 'Questo plug-in richiede la libreria @lib@',
	'plugin_necessite_plugin' => 'Necessita il plug-in @plugin@ con almeno la versione @version@.', # MODIF
	'plugin_necessite_spip' => 'Necessita SPIP con almeno la versione @version@.',
	'plugin_source' => 'origine: ',
	'plugin_titre_automatique' => 'Installazione automatica',
	'plugin_titre_automatique_ajouter' => 'Aggiungere dei plug-in',
	'plugin_zip_active' => 'Continuare per attivarlo',
	'plugin_zip_adresse' => 'indicate qui sotto l’indirizzo di un file zip del plug-in da scaricare, oppure l’indirizzo di un elenco di plug-in.',
	'plugin_zip_adresse_champ' => 'Indirizzo del plug-in o dell’elenco ',
	'plugin_zip_content' => 'Esso contiene i file seguenti (@taille@),<br />pronti per essere installati nella cartella <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Il file @zip@ è stato decompresso e installato.',
	'plugin_zip_installe_rep_finie' => 'Il file @zip@ è stato decompresso e installato nella cartella @rep@',
	'plugin_zip_installer' => 'Ora è possibile installarlo.',
	'plugin_zip_telecharge' => 'Il file @zip@ è stato scaricato',
	'plugins_actifs' => '@count@ plug-in attivati.',
	'plugins_compte' => '@count@ plug-in',
	'plugins_disponibles' => '@count@ plug-in disponibili.',
	'plugins_erreur' => 'Errore nei plug-in: @plugins@',
	'plugins_liste' => 'Elenco dei plugin',
	'plugins_vue_hierarchie' => 'Struttura gerarchica',
	'plugins_vue_liste' => 'Elenco',
	'protocole_ldap' => 'Versione del protocollo:',

	// R
	'repertoire_plugins' => 'Cartella:',
	'required' => '(obbligatorio)', # MODIF

	// S
	'sans_heure' => 'ora mancante',
	'statut_admin_restreint' => 'admin limitato', # RELIRE

	// T
	'taille_cache_image' => 'Le immagini elaborate automaticamente da SPIP (icone dei documenti, titoli in formato grafico, funzioni matematiche in formato TeX...) occupano nella cartella @dir@ in tutto @taille@.',
	'taille_cache_infinie' => 'Questo sito non prevede limiti alle dimensioni della cartella della cache.',
	'taille_cache_maxi' => 'SPIP tenta di limitare le dimensioni della cartella della cache di questo sito a circa <b>@octets@</b> di dati.',
	'taille_cache_octets' => 'Attualmente la cache è di circa @octets@.', # RELIRE
	'taille_cache_vide' => 'La cache è vuota.',
	'taille_repertoire_cache' => 'Dimensioni della cartella di cache',
	'text_article_propose_publication' => 'Articolo proposto per la pubblicazione. ',
	'texte_acces_ldap_anonyme_1' => 'Alcuni server LDAP non consentono accessi anonimi. In questo caso si deve specificare un identificatore d’accesso iniziale al fine di poter poi ricercare delle informazioni nell’elenco. Nella maggior parte dei casi tuttavia, i campi seguenti potranno essere lasciati vuoti.',
	'texte_admin_effacer_01' => 'Questo commando cancella <i>tutto</i> il contenuto del database,
 compresi <i>tutti</i> i login delle redattrici e delle amministratrici. Dopo averlo eseguito, dovrai riavviare la procedura di installazione per ricreare un nuovo database e un primo ID amministrativo.',
	'texte_adresse_annuaire_1' => '(Se la rubrica è installata nella stessa macchina di questo sito, dovrai probabilmente inserire "localhost".)',
	'texte_ajout_auteur' => 'La seguente autrice è stata aggiunta all’articolo:',
	'texte_annuaire_ldap_1' => 'Se hai accesso ad una rubrica (LDAP), puoi utilizzarla per importare automaticamente delle utenti sotto SPIP.',
	'texte_article_statut' => 'Questo articolo è:',
	'texte_article_virtuel' => 'Articolo virtuale',
	'texte_article_virtuel_reference' => '<b>Articolo virtuale:</b> articolo citato nel tuo sito SPIP, ma reindrizzato verso un’altro URL. Per eliminare il reindirizzamento, cancella l’URL qui sopra.',
	'texte_aucun_resultat_auteur' => 'Nessun risultato per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Questo sito può costantemente visualizzare la lista delle redattrici collegate, permettendo lo scambio di messaggi in tempo reale. Si può però decidere di non comparire in questo elenco (rendendosi quindi «invisibili» alle altre utenti).',
	'texte_auteurs' => 'LE AUTRICI',
	'texte_choix_base_1' => 'Scegli il database:',
	'texte_choix_base_2' => 'Il server SQL contiene diversi database.',
	'texte_choix_base_3' => '<b>Seleziona</b> quello che è stato attribuito al tuo dominio:',
	'texte_choix_table_prefix' => 'Prefisso delle tabelle:',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementi',
	'texte_conflit_edition_correction' => 'Controllare qui sotto le differenze tra le due versioni del testo; è possibile anche copiare le modifiche e poi ricominciare.',
	'texte_connexion_mysql' => 'Consulta le informazioni fornite dal tuo hoster: devi poterci trovare, i codici di collegamento alla base di dati.',
	'texte_contenu_article' => 'Contenuto dell’articolo in poche parole (<em>abstract</em>)',
	'texte_contenu_articles' => 'A seconda del modello di presentazione adottato per il sito, puoi decidere
che alcuni elementi degli articoli siano utilizzati oppure no.
Serviti dell’elenco qui sotto per indicare quali elementi rendere disponibili.',
	'texte_crash_base' => 'Se il database è stato danneggiato, puoi tentare un ripristino automatico.',
	'texte_creer_rubrique' => 'Prima di poter scrivere degli articoli,<br /> devi creare una rubrica.',
	'texte_date_creation_article' => 'DATA DI CREAZIONE DELL’ARTICOLO:',
	'texte_date_publication_anterieure' => 'DATA DI REDAZIONE ANTERIORE',
	'texte_date_publication_anterieure_nonaffichee' => 'Non visualizzare la data di redazione anteriore.',
	'texte_date_publication_article' => 'DATA DI PUBBLICAZIONE:',
	'texte_descriptif_rapide' => 'Descrizione rapida',
	'texte_effacer_base' => 'Cancella il database SPIP',
	'texte_effacer_statistiques' => 'Cancellare le statistiche',
	'texte_en_cours_validation' => 'I contenuti qui di seguito sono in attesa di validazione. ', # RELIRE
	'texte_enrichir_mise_a_jour' => 'Puoi arricchire la formattazione del testo utilizzando le «scorciatoie tipografiche»',
	'texte_fichier_authent' => '<b>SPIP deve creare i file speciali
<tt>.htpasswd</tt> e <tt>.htpasswd-admin</tt> nella cartella @dossier@ ?</b>
<p>Questi file possono servire a limitare l’accesso alle autrici
e alle amministratrici in particolari aree del vostro sito (per esempio, per un programma esterno di statistiche).</p>
<p>Se ciò non è necessario, lasciare quest’opzione al suo valore predefinito (nessuna creazione 
di file).</p>', # RELIRE
	'texte_informations_personnelles_1' => 'Il sistema creerà un tuo accesso personalizzato al sito.',
	'texte_informations_personnelles_2' => '(Nota : trattandosi di una reinstallazione, se il tuo accesso funziona ancora potete ', # RELIRE
	'texte_introductif_article' => 'Testo introduttivo dell’articolo',
	'texte_jeu_caractere' => 'Si consiglia di utilizzare sul proprio sito l’alfabeto universale (<tt>utf-8</tt>): esso permette di visualizzare i testi in tutte le lingue e non pone problemi di compatibilità con i browser moderni.',
	'texte_jeu_caractere_3' => 'Il tuo sito usa attualmente il set di caratteri:',
	'texte_jeu_caractere_4' => 'Se ciò non corrisponde alla realtà dei propri dati (a causa, per esempio, di un ripristino del database), o se  <em>si avvia il sito</em> e si desidera partire con un altro set di caratteri è necessario indicare quest’ultimo qui:',
	'texte_login_ldap_1' => '(Lascia vuoto per un accesso anonimo, o inserisci il percorso completo, per esempio «<tt>uid=rossi, ou=users, dc=mio-dominio, dc=com</tt> ».)',
	'texte_login_precaution' => 'Attenzione! Questo è l’ID con il quale sei attualmente collegato.
Utilizza questo modulo con cognizione di causa...',
	'texte_messagerie_agenda' => 'La messageria permette alle redattrici del sito di comunicare tra loro in maniera diretta nell’area riservata. Essa è associata a una agenda.',
	'texte_mise_a_niveau_base_1' => 'Hai aggiornato i file SPIP.
Adesso è necessario aggiornare il database.',
	'texte_modifier_article' => 'Modifica l’articolo:',
	'texte_multilinguisme' => 'Se desideri gestire gli articoli in diverse lingue, con un sistema di navigazione complesso, è possibile aggiungere un menu di selezione della lingua negli articoli e/o nelle rubriche, in funzione della struttura del sito.', # RELIRE
	'texte_multilinguisme_trad' => 'È anche possibile attivare un sistema di gestione di link fra le diverse traduzioni relative ad alcuni elementi.', # RELIRE
	'texte_non_compresse' => '<i>non compresso</i> (il tuo server non supporta questa funzionalità)',
	'texte_nouvelle_version_spip_1' => 'Hai installato una nuova versione di SPIP.',
	'texte_nouvelle_version_spip_2' => 'Questa nuova versione necessita un aggiornamento più radicale del solito. Se sei la webmistress del sito, cancella il file @connect@ e riprendi l’installazione al fine di aggiornare i parametri di connessione al database.<p> (NB: se hai dimenticato i parametri di connessione, rileggi il file @connect@ prima di cancellarlo...)</p>', # RELIRE
	'texte_operation_echec' => 'Torna alla pagina precedente, seleziona un altro database o creane uno nuovo. Verifica le informazioni fornite dal tuo hoster.',
	'texte_plus_trois_car' => 'più di tre caratteri',
	'texte_plusieurs_articles' => 'Diversi autori trovati per "@cherche_auteur@":',
	'texte_port_annuaire' => '(Il valore predefinito è in genere quello adatto.)',
	'texte_presente_plugin' => 'Questa pagina elenca i plugin disponibili sul sito. È possibile attivare i plugin necessari selezionando la casella corrispondente.',
	'texte_proposer_publication' => 'Quando l’articolo è completo,<br /> puoi proporne la pubblicazione.',
	'texte_proxy' => 'In alcuni casi (intranet, reti protette...), i siti distanti (documetazione di SPIP, siti in syndication, ecc.) sono accessibili unicamente attraverso un <i>proxy HTTP</i>. In questo caso, va indicato l’indirizzo del server nella forma @proxy_en_cours@. In genere questa casella va lasciata vuota.',
	'texte_publication_articles_post_dates' => 'Come si deve comportare SPIP quando gli articoli hanno
una data di pubblicazione impostata nel futuro?',
	'texte_rappel_selection_champs' => '[Non dimenticare di impostare correttamente questo campo]',
	'texte_recalcul_page' => 'Se vuoi rigenerare
una sola pagina, utilizza piuttosto lo spazio pubblico e clicca sul pulsante «rigenera».',
	'texte_recuperer_base' => 'Ripara il database',
	'texte_reference_mais_redirige' => 'articolo catalogato nel tuo sito SPIP, ma con reindirizzamento verso un altro URL.',
	'texte_requetes_echouent' => '<b>Quando alcune query SQL falliscono
ripetutamente e senza un chiaro motivo, è possibile
che sia per colpa del database
stesso.</b><p>
Il vostro server SQL dispone di una funzione di ripristino delle tabelle
danneggiate
inavvertitamente. È possibile tentare il ripristino; in
caso di errore, conservate una copia del messaggio visualizzato, contenente,
forse, delle informazioni preziose...</p><p>
Se il problema persiste, contattate la vostra
webmistress.</p>', # RELIRE
	'texte_selection_langue_principale' => 'Puoi selezionare qui sotto la «lingua predefinita» del sito. Questa scelta non obbliga - fortunatamente! - a scrivere gli articoli nella stessa lingua, ma permette di determinare:
<ul><li> il formato di default delle date sul sito pubblico;</li>
<li> la tipologia di motore tipografico che SPIP deve utilizzare per la resa del testo;</li>
<li> la lingua utilizzata nelle finestre di dialogo del sito pubblico;</li>
<li> la lingua di default nell’area riservata all’amministrazione.</li></ul>',
	'texte_sous_titre' => 'Sottotitolo',
	'texte_statistiques_visites' => '(barre scure:  domenica / curve scure: evoluzione della media)',
	'texte_statut_attente_validation' => 'in attesa di convalida',
	'texte_statut_publies' => 'pubblicato on line',
	'texte_statut_refuses' => 'rifiutati',
	'texte_suppression_fichiers' => 'Utilizza questo commando per cancellare tutti i file presenti nella
cache di SPIP. Ciò permette ad esempio di forzare la rigenerazione di tutte le pagine se hai fatto delle importanti modifiche di grafica o di struttura del sito.',
	'texte_sur_titre' => 'Occhiello',
	'texte_table_ok' => ': questa tabella è OK.',
	'texte_tentative_recuperation' => 'Tentativo di ripristino',
	'texte_tenter_reparation' => 'Tenta un ripristino del database',
	'texte_test_proxy' => 'Per fare una prova di questo proxy, indicare qui l’indirizzo
di un sito Web da testare.',
	'texte_titre_02' => 'Titolo:',
	'texte_titre_obligatoire' => '<b>Titolo</b> [Obbligatorio]',
	'texte_travail_article' => '@nom_auteur_modif@ ha lavorato su questo articolo @date_diff@ minuti fa',
	'texte_travail_collaboratif' => 'Se diverse autrici lavorano spesso sullo stesso articolo,
il sistema può segnalare gli articoli «aperti»
di recente al fine di evitare modifiche simultanee.
Questa opzione è disattivata di default
per evitare di generare messaggi d’avvertimento intempestivi.',
	'texte_vide' => 'vuoto',
	'texte_vider_cache' => 'Svuota la cache',
	'titre_admin_tech' => 'Manutenzione tecnica',
	'titre_admin_vider' => 'Manutenzione tecnica',
	'titre_cadre_afficher_article' => 'Visualizza gli articoli',
	'titre_cadre_afficher_traductions' => 'Visualizzare lo stato delle traduzioni per le seguenti lingue:',
	'titre_cadre_ajouter_auteur' => 'AGGIUNGI UN’AUTRICE: ',
	'titre_cadre_interieur_rubrique' => 'All’interno della rubrica',
	'titre_cadre_numero_auteur' => 'AUTRICE NUMERO',
	'titre_cadre_signature_obligatoire' => '<b>Firma</b> [Obbligatoria]<br />',
	'titre_config_contenu_notifications' => 'Notifiche',
	'titre_config_contenu_prive' => 'Nell’area riservata',
	'titre_config_contenu_public' => 'Sul sito pubblico',
	'titre_config_fonctions' => 'Configurazione del sito',
	'titre_configuration' => 'Configurazione del sito',
	'titre_conflit_edition' => 'Conflitto all’atto dell’edizione',
	'titre_connexion_ldap' => 'Opzioni: <b>La connessione LDAP</b>',
	'titre_groupe_mots' => 'GRUPPO DI PAROLE CHIAVE:',
	'titre_langue_article' => 'Lingua dell’articolo',
	'titre_langue_rubrique' => 'Lingua della rubrica',
	'titre_langue_trad_article' => 'LINGUA E TRADUZIONI DELL’ARTICOLO',
	'titre_les_articles' => 'GLI ARTICOLI',
	'titre_messagerie_agenda' => 'Messagistica e agenda',
	'titre_naviguer_dans_le_site' => 'Navigare nel sito...',
	'titre_nouvelle_rubrique' => 'Nuova rubrica',
	'titre_numero_rubrique' => 'RUBRICA NUMERO:',
	'titre_page_articles_edit' => 'Modifica: @titre@',
	'titre_page_articles_page' => 'Gli articoli',
	'titre_page_articles_tous' => 'Tutto il sito',
	'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configurazione del sito',
	'titre_page_delete_all' => 'eliminazione totale e irreversible',
	'titre_page_recherche' => 'Risultati della ricerca @recherche@',
	'titre_page_statistiques_referers' => 'Statistiche (link al tuo sito)',
	'titre_page_upgrade' => 'Aggiornamento di SPIP',
	'titre_publication_articles_post_dates' => 'Pubblicazione di articoli postdatati',
	'titre_reparation' => 'Riparazione',
	'titre_suivi_petition' => 'Monitoraggio delle petizioni',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Tutte le versioni di questo articolo:',
	'trad_delier' => 'Non collegare più a queste traduzioni', # RELIRE
	'trad_lier' => 'Questo articolo è una traduzione dell’articolo numero:',
	'trad_new' => 'Scrivere una nuova traduzione',

	// U
	'utf8_convert_erreur_orig' => 'Errore: il set di caratteri @charset@ non è supportato.',

	// V
	'version' => 'Versione:'
);
